"""Controlling the config file"""

import os
import yaml


def load_config(config_file):
    with open(config_file, 'r') as file:
        config = yaml.safe_load(file)
    return config

import matplotlib.pyplot as plt

class Plotter:
    def __init__(self, data_array, latitudes, longitudes):
        self.data_array = data_array
        self.latitudes = latitudes
        self.longitudes = longitudes

    def plot_with_markers(self, var,time_index, index_pairs, output_dir='plots'):
        """Plot data with markers at specified index pairs."""
        # Select the desired time slice
        data = self.data_array.isel(time=time_index)

        # Plot the data
        plot = data.plot()
        ax = plot.axes

        # Loop through each pair of indices and plot the markers
        for i_index, j_index in index_pairs:
            value = self.data_array.isel(time=time_index, j=j_index, i=i_index).values
            lat = self.latitudes.isel(i=i_index, j=j_index).values
            lon = self.longitudes.isel(i=i_index, j=j_index).values

            # Add marker to the plot
            ax.plot(i_index, j_index, marker='x', color='red', markersize=10)
            ax.set_title(f'i:{i_index}, j:{j_index}, lat:{lat:.1f}, lon:{lon:.1f}, value:{value:.2e}')

            # Save the plot as an image
            output_path = f'{output_dir}/{var}_images_location_{i_index}_{j_index}.png'

            os.mkdir(output_dir, exist_ok=True)
            plt.savefig(output_path)

            # Optionally print details to console
            print(f'Index: ({i_index}, {j_index}), Value: {value:.2e}, Latitude: {lat:.1f}, Longitude: {lon:.1f}')

        # Show the final plot
        plt.show()

# Usage example:
# Assuming `intpp` is your xarray dataset with variables `intpp`, `latitude`, and `longitude`
# plotter = Plotter(intpp.intpp, intpp.latitude, intpp.longitude)
# index_pairs = [(120, 290), (150, 150), (200, 150), (250, 200), (100, 200), (210, 250), (350, 150),(50, 70), (150, 100), (350, 100)]
# plotter.plot_with_markers(time_index=100, index_pairs=index_pairs)
